==> keyclic_sdk_api-1.31.2.tar.gz: lib/model/place_links.dart <==
part of keyclic_sdk_api.api;

class PlaceLinks {
  PlaceLinksSelf self = null;

  PlaceLinksOrganization organization = null;

  PlaceLinksContainedInPlace containedInPlace = null;

  PlaceLinksContainsPlaces containsPlaces = null;

  PlaceLinks();

  @override
  String toString() {
    return 'PlaceLinks[self=$self, organization=$organization, containedInPlace=$containedInPlace, containsPlaces=$containsPlaces, ]';
  }

  PlaceLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    self = new PlaceLinksSelf.fromJson(json['self']);
    organization = new PlaceLinksOrganization.fromJson(json['organization']);
    containedInPlace =
        new PlaceLinksContainedInPlace.fromJson(json['containedInPlace']);
    containsPlaces =
        new PlaceLinksContainsPlaces.fromJson(json['containsPlaces']);
  }

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'organization': organization,
      'containedInPlace': containedInPlace,
      'containsPlaces': containsPlaces
    };
  }

  static List<PlaceLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<PlaceLinks>()
        : json.map((value) => new PlaceLinks.fromJson(value)).toList();
  }

  static Map<String, PlaceLinks> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, PlaceLinks>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new PlaceLinks.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/place_links.dart <==
part of keyclic_sdk_api.api;

class PlaceLinks {
  PlaceLinksSelf self = null;

  PlaceLinksOrganization organization = null;

  PlaceLinksContainedInPlace containedInPlace = null;

  PlaceLinksContainsPlaces containsPlaces = null;

  PlaceLinks({
    this.self,
    this.organization,
    this.containedInPlace,
    this.containsPlaces,
  });

  @override
  String toString() {
    return 'PlaceLinks[self=$self, organization=$organization, containedInPlace=$containedInPlace, containsPlaces=$containsPlaces, ]';
  }

  PlaceLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    self = new PlaceLinksSelf.fromJson(json['self']);
    organization = new PlaceLinksOrganization.fromJson(json['organization']);
    containedInPlace =
        new PlaceLinksContainedInPlace.fromJson(json['containedInPlace']);
    containsPlaces =
        new PlaceLinksContainsPlaces.fromJson(json['containsPlaces']);
  }

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'organization': organization,
      'containedInPlace': containedInPlace,
      'containsPlaces': containsPlaces,
    };
  }

  static List<PlaceLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<PlaceLinks>()
        : json.map((value) => new PlaceLinks.fromJson(value)).toList();
  }

  static Map<String, PlaceLinks> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, PlaceLinks>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new PlaceLinks.fromJson(value));
    }
    return map;
  }
}
